@@ -1,6 +1,7 @@
 import struct
 import socket
 import logging
+import zlib
 
 try:
     from cPickle import loads, dumps
@@ -112,8 +113,8 @@ class Server(object):
         if bodylen:
             extra_content = self._read_socket(bodylen)
 
-        return (magic, opcode, keylen, extlen, datatype, status, bodylen, opaque,
-            cas, extra_content)
+        return (magic, opcode, keylen, extlen, datatype, status, bodylen,
+            opaque, cas, extra_content)
 
     def authenticate(self, username, password):
         logger.info('Authenticating as %s' % username)
@@ -168,19 +169,23 @@ class Server(object):
             flags |= self.FLAGS['pickle']
             value = dumps(value)
 
-        # TODO: Compression
+        value = zlib.compress(value)
+        flags |= self.FLAGS['compressed']
         return (flags, value)
 
     def deserialize(self, value, flags):
-        if flags == 0:
-            return value
-        elif flags & self.FLAGS['integer']:
+        if flags & self.FLAGS['compressed']:
+            value = zlib.decompress(value)
+
+        if flags & self.FLAGS['integer']:
             return int(value)
         elif flags & self.FLAGS['long']:
             return long(value)
         elif flags & self.FLAGS['pickle']:
             return loads(value)
 
+        return value
+
     def get(self, key):
         logger.info('Getting key %s' % key)
         self.connection.send(struct.pack(self.HEADER_STRUCT + \
@@ -208,8 +213,6 @@ class Server(object):
 
         flags, value = struct.unpack('!L%ds' % (bodylen - 4, ), extra_content)
 
-        logger.debug('Value "%s"' % value)
-
         return self.deserialize(value, flags)
 
     def set(self, key, value, time):
